.icon
  @extend .fa
.icon-home
  @extend .fa-home
.icon-search
  @extend .fa-search
.icon-book
  @extend .fa-book
.icon-caret-down
  @extend .fa-caret-down
.icon-github
  @extend .fa-github
.icon-bitbucket
  @extend .fa-bitbucket
.icon-gitlab
  @extend .fa-gitlab
.icon-fire
  @extend .fa-fire
.icon-circle-arrow-right
  @extend .fa-arrow-circle-right
.icon-circle-arrow-left
  @extend .fa-arrow-circle-left
.icon-link
  @extend .fa-link
